summaryrefslogtreecommitdiffstats
path: root/lib/kpilotdevicelink.h
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2011-12-16 09:57:02 -0600
committerTimothy Pearson <[email protected]>2011-12-16 09:57:02 -0600
commitd55caffa62947ca831ae0c21aada3b55eec24027 (patch)
tree8a2a0ff56d7023011016a7e385f0f3b60ffea095 /lib/kpilotdevicelink.h
parent631a19d8c5c5f69dc0d941c1997806fb422c79a6 (diff)
downloadkpilot-d55caffa62947ca831ae0c21aada3b55eec24027.tar.gz
kpilot-d55caffa62947ca831ae0c21aada3b55eec24027.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 631a19d8c5c5f69dc0d941c1997806fb422c79a6.
Diffstat (limited to 'lib/kpilotdevicelink.h')
-rw-r--r--lib/kpilotdevicelink.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/lib/kpilotdevicelink.h b/lib/kpilotdevicelink.h
index 6fe02ef..c4fb9f3 100644
--- a/lib/kpilotdevicelink.h
+++ b/lib/kpilotdevicelink.h
@@ -42,7 +42,7 @@ class DeviceCommThread; ///< Thread for doing all palm device communications
* it waits for the actual device to become available, and
* then becomes ready to handle syncing.
*/
-enum LinkStatus {
+enum LinktqStatus {
Init,
WaitingForDevice,
FoundDevice,
@@ -100,15 +100,15 @@ public:
/**
* Get the status (state enum) of this link.
* @return The LinkStatus enum for the link's current state.
*/
- LinkStatus status() const
+ LinktqStatus status() const
{
- return fLinkStatus;
+ return fLinktqStatus;
}
/** Get a human-readable string for the given status @p l. */
- static TQString statusString(LinkStatus l);
+ static TQString statusString(LinktqStatus l);
// The following API is the actual implementation of
// the KPilotLink API, for documentation see that file.
@@ -141,7 +141,7 @@ protected:
private:
- LinkStatus fLinkStatus;
+ LinktqStatus fLinktqStatus;
public:
@@ -100,15 +100,15 @@ public:
/**
* Get the status (state enum) of this link.
- * @return The LinkStatus enum for the link's current state.
+ * @return The LinktqStatus enum for the link's current state.
*/